<?php
/**
 * Plugin Name: Fedya's text obfuscator
 * Plugin URI: https://fedia.eu/fedyas-text-obfuscator/
 * Description: Плъгин за защита на текстово съдържание чрез обфускация
 * Version: 1.0.4
 * Author: Fedya Serafiev
 * Author URI: https://fedia.eu
 * Text Domain: text-obfuscator
 * Domain Path: /languages
 * License: GPL v2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */

// Prevent direct access to this file
if (!defined('ABSPATH')) {
    exit;
}

// Проверка за минимална версия на WordPress
if (version_compare(get_bloginfo('version'), '5.0', '<')) {
    add_action('admin_notices', function() {
        echo '<div class="error"><p>Text Obfuscator изисква WordPress версия 5.0 или по-нова.</p></div>';
    });
    return;
}

// Активационен хук
register_activation_hook(__FILE__, 'text_obfuscator_activate');
function text_obfuscator_activate() {
    // Създаваме опции по подразбиране ако е необходимо
    $default_options = array(
        'version' => '1.0.0',
        'enabled' => true
    );
    add_option('text_obfuscator_options', $default_options);
}

// Деактивационен хук
register_deactivation_hook(__FILE__, 'text_obfuscator_deactivate');
function text_obfuscator_deactivate() {
    // Изчистваме опциите ако е необходимо
    // delete_option('text_obfuscator_options');
}

// Регистрираме CSS файла
add_action('admin_enqueue_scripts', 'register_plugin_styles');
function register_plugin_styles() {
    wp_enqueue_style(
        'text-obfuscator-styles',
        plugins_url('css/text-obfuscator-admin.css', __FILE__)
    );
}

// Добавяме линк "Още детайли" в менюто на плъгините
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'add_plugin_details_link');
function add_plugin_details_link($links) {
    $details_link = '<a href="' . esc_url(admin_url('admin.php?page=text-obfuscator-details')) . '">Още детайли</a>';
    array_unshift($links, $details_link);
    return $links;
}

// Добавяме страницата "Още детайли" в админ менюто
add_action('admin_menu', 'add_plugin_details_page');
function add_plugin_details_page() {
    add_menu_page(
        'Text Obfuscator - Още детайли',
        'Text Obfuscator',
        'manage_options',
        'text-obfuscator-details',
        'display_plugin_details',
        'dashicons-shield',
        100
    );
}

// Добавяме предупредителен текст
add_filter('the_content', 'add_copyright_notice');
function add_copyright_notice($content) {
    // Проверяваме дали сме в single post view
    if (!is_single()) {
        return $content;
    }
    
    $notice = sprintf(
        '<div class="copyright-notice">%s</div>',
        esc_html__('Това съдържание е защитено с авторски права. При копиране, моля цитирайте източника.', 'text-obfuscator')
    );
    
    return $content . $notice;
}

// Регистрираме и зареждаме JS файла
add_action('wp_enqueue_scripts', 'text_obfuscator_scripts');
function text_obfuscator_scripts() {
    // Проверяваме дали обфускацията е включена
    $options = get_option('text_obfuscator_options');
    if (!empty($options['enabled'])) {
        wp_enqueue_script(
            'text-obfuscator',
            plugins_url('js/text-obfuscator.js', __FILE__),
            array(),
            '1.0.0',
            true
        );
    }
}

// Функция за показване на съдържанието на страницата
function display_plugin_details() {
    // Проверка за права
    if (!current_user_can('manage_options')) {
        wp_die(__('Нямате достатъчно права за достъп до тази страница.', 'text-obfuscator'));
    }
    ?>
    <div class="wrap text-obfuscator-details">
        <h1><?php echo esc_html__('Text Obfuscator - Подробна информация', 'text-obfuscator'); ?></h1>
        
        <div class="functionality-section">
            <h2><?php echo esc_html__('Функционалности', 'text-obfuscator'); ?></h2>
            <ul>
                <li><?php echo esc_html__('Автоматична замяна на латински букви с кирилски еквиваленти и обратно', 'text-obfuscator'); ?></li>
                <li><?php echo esc_html__('Добавяне на невидими Unicode маркери', 'text-obfuscator'); ?></li>
                <li><?php echo esc_html__('Произволна промяна на регистъра на буквите', 'text-obfuscator'); ?></li>
                <li><?php echo esc_html__('Поддръжка на разширен набор от символи', 'text-obfuscator'); ?></li>
            </ul>
        </div>

        <div class="how-it-works-section">
            <h2><?php echo esc_html__('Как работи', 'text-obfuscator'); ?></h2>
            <p><?php echo esc_html__('При копиране на текст от вашия сайт, разширението:', 'text-obfuscator'); ?></p>
            <ol>
                <li><?php echo esc_html__('Прихваща събитието за копиране', 'text-obfuscator'); ?></li>
                <li><?php echo esc_html__('Взима селектирания текст', 'text-obfuscator'); ?></li>
                <li>
                    <?php echo esc_html__('Прилага обфускация чрез:', 'text-obfuscator'); ?>
                    <ul>
                        <li><?php echo esc_html__('Замяна на визуално идентични символи', 'text-obfuscator'); ?></li>
                        <li><?php echo esc_html__('Добавяне на невидими Unicode маркери', 'text-obfuscator'); ?></li>
                        <li><?php echo esc_html__('Произволна промяна на регистъра на буквите', 'text-obfuscator'); ?></li>
						<li><?php echo esc_html__('Автоматично добавя информация за източника при копиране на текст', 'text-obfuscator'); ?></li>
						<li><?php echo esc_html__('Показва предупреждение за авторските права', 'text-obfuscator'); ?></li>
                    </ul>
                </li>
                <li><?php echo esc_html__('Записва обфускирания текст в клипборда', 'text-obfuscator'); ?></li>
            </ol>
        </div>
    </div>
    <?php
}